==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/networkanalytics/kotlin/inputs/DataProductNetworkAclsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkanalytics.kotlin.inputs

import com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder
import com.pulumi.azurenative.networkanalytics.kotlin.enums.DefaultAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Data Product Network rule set
 * @property allowedQueryIpRangeList The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
 * @property defaultAction Default Action
 * @property ipRules IP rule with specific IP or IP range in CIDR format.
 * @property virtualNetworkRule Virtual Network Rule
 */
public data class DataProductNetworkAclsArgs(
    public val allowedQueryIpRangeList: Output<List<String>>,
    public val defaultAction: Output<Either<String, DefaultAction>>,
    public val ipRules: Output<List<IPRulesArgs>>,
    public val virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs> {
    override fun toJava(): com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs =
        com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder()
            .allowedQueryIpRangeList(
                allowedQueryIpRangeList.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .defaultAction(
                defaultAction.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipRules(
                ipRules.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .virtualNetworkRule(
                virtualNetworkRule.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataProductNetworkAclsArgs].
 */
@PulumiTagMarker
public class DataProductNetworkAclsArgsBuilder internal constructor() {
    private var allowedQueryIpRangeList: Output<List<String>>? = null

    private var defaultAction: Output<Either<String, DefaultAction>>? = null

    private var ipRules: Output<List<IPRulesArgs>>? = null

    private var virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>? = null

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("uggrugskvnivhmlc")
    public suspend fun allowedQueryIpRangeList(`value`: Output<List<String>>) {
        this.allowedQueryIpRangeList = value
    }

    @JvmName("rqywwyusrlcgcihs")
    public suspend fun allowedQueryIpRangeList(vararg values: Output<String>) {
        this.allowedQueryIpRangeList = Output.all(values.asList())
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("jwmrnnhknlwuuoap")
    public suspend fun allowedQueryIpRangeList(values: List<Output<String>>) {
        this.allowedQueryIpRangeList = Output.all(values)
    }

    /**
     * @param value Default Action
     */
    @JvmName("xcatxrxkfxmeijwo")
    public suspend fun defaultAction(`value`: Output<Either<String, DefaultAction>>) {
        this.defaultAction = value
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("oygpxdtgvjbhqrcf")
    public suspend fun ipRules(`value`: Output<List<IPRulesArgs>>) {
        this.ipRules = value
    }

    @JvmName("nbkuhbnuxgawjwjr")
    public suspend fun ipRules(vararg values: Output<IPRulesArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("mlfglfvhxxmxupyb")
    public suspend fun ipRules(values: List<Output<IPRulesArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("byhcbxvwvaprcxbh")
    public suspend fun virtualNetworkRule(`value`: Output<List<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = value
    }

    @JvmName("sxrksqcpmtpgvbxa")
    public suspend fun virtualNetworkRule(vararg values: Output<VirtualNetworkRuleArgs>) {
        this.virtualNetworkRule = Output.all(values.asList())
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("bqehaftfpnwclwuv")
    public suspend fun virtualNetworkRule(values: List<Output<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = Output.all(values)
    }

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("amauoxaagltrendk")
    public suspend fun allowedQueryIpRangeList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("vycqcrxegocotbyu")
    public suspend fun allowedQueryIpRangeList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("wcwdyaciiciacitb")
    public suspend fun defaultAction(`value`: Either<String, DefaultAction>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("qibeotdhbfvnjbvp")
    public fun defaultAction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("hushwgpknvuqigqh")
    public fun defaultAction(`value`: DefaultAction) {
        val toBeMapped = Either.ofRight<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("orwydtarbvknixmw")
    public suspend fun ipRules(`value`: List<IPRulesArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("eccggqqqkxvjhgby")
    public suspend fun ipRules(argument: List<suspend IPRulesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("epdubvhhnfmauppn")
    public suspend fun ipRules(vararg argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("tffxdidsbysrthxf")
    public suspend fun ipRules(argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRulesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("vrvwnasbdhnvsxep")
    public suspend fun ipRules(vararg values: IPRulesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("xdxawbdogyhcubnr")
    public suspend fun virtualNetworkRule(`value`: List<VirtualNetworkRuleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("bqbglwtqucumhtlt")
    public suspend
    fun virtualNetworkRule(argument: List<suspend VirtualNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("rmepfaryktkpmucm")
    public suspend fun virtualNetworkRule(
        vararg
        argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("tmtnjskostbnfjme")
    public suspend
    fun virtualNetworkRule(argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualNetworkRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("jbghetuixjfttusc")
    public suspend fun virtualNetworkRule(vararg values: VirtualNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    internal fun build(): DataProductNetworkAclsArgs = DataProductNetworkAclsArgs(
        allowedQueryIpRangeList = allowedQueryIpRangeList ?: throw
            PulumiNullFieldException("allowedQueryIpRangeList"),
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules ?: throw PulumiNullFieldException("ipRules"),
        virtualNetworkRule = virtualNetworkRule ?: throw PulumiNullFieldException("virtualNetworkRule"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/networkanalytics/kotlin/inputs/DataProductNetworkAclsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkanalytics.kotlin.inputs

import com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder
import com.pulumi.azurenative.networkanalytics.kotlin.enums.DefaultAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Data Product Network rule set
 * @property allowedQueryIpRangeList The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
 * @property defaultAction Default Action
 * @property ipRules IP rule with specific IP or IP range in CIDR format.
 * @property virtualNetworkRule Virtual Network Rule
 */
public data class DataProductNetworkAclsArgs(
    public val allowedQueryIpRangeList: Output<List<String>>,
    public val defaultAction: Output<Either<String, DefaultAction>>,
    public val ipRules: Output<List<IPRulesArgs>>,
    public val virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs> {
    override fun toJava(): com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs =
        com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder()
            .allowedQueryIpRangeList(
                allowedQueryIpRangeList.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .defaultAction(
                defaultAction.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipRules(
                ipRules.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .virtualNetworkRule(
                virtualNetworkRule.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataProductNetworkAclsArgs].
 */
@PulumiTagMarker
public class DataProductNetworkAclsArgsBuilder internal constructor() {
    private var allowedQueryIpRangeList: Output<List<String>>? = null

    private var defaultAction: Output<Either<String, DefaultAction>>? = null

    private var ipRules: Output<List<IPRulesArgs>>? = null

    private var virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>? = null

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("ooyxooalukanogsi")
    public suspend fun allowedQueryIpRangeList(`value`: Output<List<String>>) {
        this.allowedQueryIpRangeList = value
    }

    @JvmName("ytisbvkuyyyflewr")
    public suspend fun allowedQueryIpRangeList(vararg values: Output<String>) {
        this.allowedQueryIpRangeList = Output.all(values.asList())
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("goetfqyfmuaefulg")
    public suspend fun allowedQueryIpRangeList(values: List<Output<String>>) {
        this.allowedQueryIpRangeList = Output.all(values)
    }

    /**
     * @param value Default Action
     */
    @JvmName("mvnvsbaooqpcotwq")
    public suspend fun defaultAction(`value`: Output<Either<String, DefaultAction>>) {
        this.defaultAction = value
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("qlwlckedwcyfqptl")
    public suspend fun ipRules(`value`: Output<List<IPRulesArgs>>) {
        this.ipRules = value
    }

    @JvmName("fcudvebdpfmelyqu")
    public suspend fun ipRules(vararg values: Output<IPRulesArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("xuhdwyeffosmbtvv")
    public suspend fun ipRules(values: List<Output<IPRulesArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("ppacvvrrurviltns")
    public suspend fun virtualNetworkRule(`value`: Output<List<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = value
    }

    @JvmName("iyncqyqnrswmtsrf")
    public suspend fun virtualNetworkRule(vararg values: Output<VirtualNetworkRuleArgs>) {
        this.virtualNetworkRule = Output.all(values.asList())
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("ktvfihuqucatbbeg")
    public suspend fun virtualNetworkRule(values: List<Output<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = Output.all(values)
    }

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("fcajaxiebhyorqmd")
    public suspend fun allowedQueryIpRangeList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("iiypiguhrqonomry")
    public suspend fun allowedQueryIpRangeList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("wcsiyalyuysgwwxq")
    public suspend fun defaultAction(`value`: Either<String, DefaultAction>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("gbpanyfgphegugrm")
    public fun defaultAction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("pxmxspulqbfxlifa")
    public fun defaultAction(`value`: DefaultAction) {
        val toBeMapped = Either.ofRight<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("xnqudlkhihtnbbgh")
    public suspend fun ipRules(`value`: List<IPRulesArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("qhgqdvjwyvyjqrnq")
    public suspend fun ipRules(argument: List<suspend IPRulesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("lngqpsjixnrlrwre")
    public suspend fun ipRules(vararg argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("prbrwpdoykviwpen")
    public suspend fun ipRules(argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRulesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("omirceelcynpuoml")
    public suspend fun ipRules(vararg values: IPRulesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("cqxkfnuphiakyxkc")
    public suspend fun virtualNetworkRule(`value`: List<VirtualNetworkRuleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("ilirswuaptpsrqdu")
    public suspend
    fun virtualNetworkRule(argument: List<suspend VirtualNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("wxmlbolkryjdobfw")
    public suspend fun virtualNetworkRule(
        vararg
        argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("ttovatumrmbemapn")
    public suspend
    fun virtualNetworkRule(argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualNetworkRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("rwmcfryjviwtenvb")
    public suspend fun virtualNetworkRule(vararg values: VirtualNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    internal fun build(): DataProductNetworkAclsArgs = DataProductNetworkAclsArgs(
        allowedQueryIpRangeList = allowedQueryIpRangeList ?: throw
            PulumiNullFieldException("allowedQueryIpRangeList"),
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules ?: throw PulumiNullFieldException("ipRules"),
        virtualNetworkRule = virtualNetworkRule ?: throw PulumiNullFieldException("virtualNetworkRule"),
    )
}
